Changelog
=========

Version 0.1.1
-------------
Added the ability to change the units and radial coordinates of a
`psipy.model.Variable`. There are two new examples showing how to do this in
the example gallery.

Version 0.1
-----------
First PsiPy release.
